<?php


/*
 * plugin.php has to load to know which plugin is active
 */
require_once( ABSPATH . 'wp-admin/includes/plugin.php' );


if ( ! function_exists( 'firnera_lite_setup' ) ) :

function firnera_lite_setup() {
///////////////////////
// TITLE TAG SUPPORT
///////////////////////
add_theme_support( 'title-tag' );

///////////////////////
// Localization Support
///////////////////////
load_theme_textdomain( 'firnera-lite', get_template_directory().'/languages' );
$locale = get_locale();
$locale_file = get_template_directory().'/languages/$locale.php';
if ( is_readable($locale_file) )
    require_once($locale_file);




///////////////////////
/// Add Menu Support
///////////////////////

register_nav_menu('firnera-main', __('Main Navigation Menu','firnera-lite'));


///////////////////////
/// Background Support
///////////////////////
$firnera_lite_background = array(
	'default-image' => '%1$s/images/firdausSquarborpng.png',
	'default-position-x'     => 'center',
	'default-color' => '222222'
);
add_theme_support( 'custom-background', $firnera_lite_background );

// Indicate widget sidebars can use selective refresh in the Customizer.
add_theme_support( 'customize-selective-refresh-widgets' );

///////////////////////
/// Misc
///////////////////////
add_theme_support('automatic-feed-links' );


define('firnera_lite_theme_url','http://fffthemes.com/free-themes/firnera-lite-wordpress-theme');

	//////////////////////////
	/// Custom Logo
	/////////////////////////

    $firnera_lite_custom_logo = array(
        'height'      => 100,
        'width'       => 300,
        'flex-width'  => true,
    );
    add_theme_support( 'custom-logo', $firnera_lite_custom_logo );




///////////////////////
// Featured Image
///////////////////////
add_theme_support( 'post-thumbnails');
set_post_thumbnail_size( 300, 224, true );
add_image_size( 'firnera-left-thumb',300 ,224, true );



///////////////////////
// Add Woocommerce Support 
///////////////////////

add_theme_support( 'woocommerce' );

add_theme_support( 'wc-product-gallery-zoom' );
add_theme_support( 'wc-product-gallery-lightbox' );
add_theme_support( 'wc-product-gallery-slider' );

}
endif; 
add_action( 'after_setup_theme', 'firnera_lite_setup' );


///////////////////////
// Add Sidebar
///////////////////////
function firnera_lite_add_sidebar_widgets() {
	register_sidebar(array(
		'name'=> esc_html__('Sidebar Right Post','firnera-lite'),
		'id' => 'firnera-post-right-sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
		'description' => esc_html__('NOTE: Recommended width is 300px.','firnera-lite')
	));
	
	register_sidebar( array(
		'name' => esc_html__('Firnera Woocommerce Widgets','firnera-lite'),
		'id' => 'firnera-firnera-woocommerce-widgets',
		'description' => esc_html__('Note: Woocommerce Sidebar','firnera-lite'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	) );
	
	
	register_sidebar(array(
		'name' => esc_html__('Sidebar Widgets Ads After Menu','firnera-lite'),
		'id' => 'firnera-custom-sidebar-after-menu',
		'description' => esc_html__('Note: This Advertisement. Important: Use Text widgets to insert code','firnera-lite'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name' => esc_html__('Sidebar Widgets Ads Before Footer','firnera-lite'),
		'id' => 'firnera-custom-sidebar-before-footer',
		'description' => esc_html__('Note: This Advertisement. Important: Use Text widgets to insert code','firnera-lite'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	));

}
add_action( 'widgets_init', 'firnera_lite_add_sidebar_widgets' );

/////////////////////////////////////
// Add Content Limit
/////////////////////////////////////

function firnera_lite_excerpt($limit) {
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
  return $excerpt;
}

function firnera_lite_content($limit) {
  $content = explode(' ', get_the_content(), $limit);
  if (count($content)>=$limit) {
    array_pop($content);
    $content = implode(" ",$content).'...';
  } else {
    $content = implode(" ",$content);
  }
  $content = preg_replace('/\[.+\]/','', $content);
  $content = apply_filters('the_content', $content);
  $content = str_replace(']]>', ']]&gt;', $content);
  return $content;
}	


/* 
pass Parameter with url
Plugin URI: http://webopius.com/
Description: A plugin to allow parameters to be passed in the URL and recognized by WordPress
Author: Adam Boyse
Version: 1.0
Author URI: http://www.webopius.com/
*/
add_filter('query_vars', 'firnera_lite_parameter_queryvars' );
function firnera_lite_parameter_queryvars( $qvars )
{
$qvars[] = 'all';
return $qvars;
}


if(get_theme_mod('firnera-lite_customizer_exclude_page_from_search_on_or_off',true)){
	 
	///////////////////////
	//Exclude page from search
	///////////////////////
	if (!is_admin())	{
	function firnera_lite_SearchFilter($query) {
		if ($query->is_search) {
			$query->set('post_type', 'post');
		}
			return $query;
		}
		add_filter('pre_get_posts','firnera_lite_SearchFilter');
	}

}

function firnera_lite_numeric_pagination(){
	echo '<div id="firnera-lite-navigation">';
	the_posts_pagination( array(
		'mid_size' => 2,
		'prev_text' => __( '<i class="fa fa-chevron-circle-left"></i>&nbsp;Prev', 'firnera-lite' ),
		'next_text' => __( 'Next&nbsp;<i class="fa fa-chevron-circle-right"></i>', 'firnera-lite' ),
	));
	echo '</div>';
}
 
///////////////////////
/// Content Width
///////////////////////
if ( ! isset( $content_width ) ) {
	$content_width = 660;
}
function firnera_lite_scripts() {
	wp_enqueue_style('firnera-lite-style', get_stylesheet_uri() );
	wp_enqueue_style('firnera-lite-fontawesome-css', get_template_directory_uri() . '/include/font-awesome-4.7.0/css/font-awesome.min.css');	
	wp_enqueue_style('firnera-lite-responsive', get_template_directory_uri() . '/css/responsive.css');
	wp_enqueue_style('firnera-lite-meanmenu', get_template_directory_uri() . '/css/meanmenu.css');
	wp_enqueue_style('firnera-lite-table', get_template_directory_uri() . '/css/table.css');
	
	wp_enqueue_script('firnera-lite-custom', get_template_directory_uri() . '/scripts/firnera-lite-custom.js', 'jquery', '1.0.0', true);
	wp_enqueue_script('firnera-lite-meanmenu', get_template_directory_uri() . '/scripts/jquery.meanmenu.js', 'jquery', '2.0.8', true);
	wp_enqueue_script('firnera-lite-load-meanmenu', get_template_directory_uri() . '/scripts/load-meanmenu.js', 'jquery', '1.0.0', true);
	
	wp_enqueue_script('jquery');
	 
	if ( is_singular() ) { 
		wp_enqueue_script( "comment-reply" );
	}
	
}
add_action( 'wp_enqueue_scripts', 'firnera_lite_scripts' );




if ( is_plugin_active( 'woocommerce/woocommerce.php' )){

	add_filter( 'woocommerce_breadcrumb_defaults', 'firnera_lite_custom_woocommerce_breadcrumbs' );
	function firnera_lite_custom_woocommerce_breadcrumbs() {
		return array(
				'delimiter'   => '<li class="fir-demiliter-bc"><i class="fa fa-angle-right"></i></li>',
				'wrap_before' => '<nav id="fir-crumbs" itemprop="breadcrumb"><ul>',
				'wrap_after'  => '</ul></nav>',
				'before' => '<li>',
				'after' => '</li>',
				'home' => _x( '<i class="fa fa-home"></i>Home', 'breadcrumb', 'firnera-lite' ),
			);
	}
}

//////////////////////////////////
//////						//////
//////    Theme Options		//////
//////					    //////
//////////////////////////////////
include(get_template_directory() . '/include/theme-options.php');



//////////////////////////////////
//////						//////
//////    Theme Info 		//////
//////					    //////
//////////////////////////////////
include(get_template_directory() . '/include/theme-info.php');